==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/RELATEDLINEARREFERENCEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for RELATEDLINEARREFERENCEDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RELATEDLINEARREFERENCEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSETDIRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFERENCETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSETDIRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFERENCETYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELATEDLINEARREFERENCEDETAILS_Type", propOrder = {
    "fromreferenceid",
    "fromoffset",
    "fromoffsetdirection",
    "fromreferencetype",
    "toreferenceid",
    "tooffset",
    "tooffsetdirection",
    "toreferencetype"
})
public class RELATEDLINEARREFERENCEDETAILS_Type {

    @XmlElement(name = "FROMREFERENCEID")
    protected LINEARREFERENCEID_Type fromreferenceid;
    @XmlElement(name = "FROMOFFSET")
    protected QUANTITY fromoffset;
    @XmlElement(name = "FROMOFFSETDIRECTION")
    protected UCODEID_Type fromoffsetdirection;
    @XmlElement(name = "FROMREFERENCETYPE")
    protected TYPE_Type fromreferencetype;
    @XmlElement(name = "TOREFERENCEID")
    protected LINEARREFERENCEID_Type toreferenceid;
    @XmlElement(name = "TOOFFSET")
    protected QUANTITY tooffset;
    @XmlElement(name = "TOOFFSETDIRECTION")
    protected UCODEID_Type tooffsetdirection;
    @XmlElement(name = "TOREFERENCETYPE")
    protected TYPE_Type toreferencetype;

    /**
     * Gets the value of the fromreferenceid property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getFROMREFERENCEID() {
        return fromreferenceid;
    }

    /**
     * Sets the value of the fromreferenceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setFROMREFERENCEID(LINEARREFERENCEID_Type value) {
        this.fromreferenceid = value;
    }

    /**
     * Gets the value of the fromoffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFROMOFFSET() {
        return fromoffset;
    }

    /**
     * Sets the value of the fromoffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFROMOFFSET(QUANTITY value) {
        this.fromoffset = value;
    }

    /**
     * Gets the value of the fromoffsetdirection property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getFROMOFFSETDIRECTION() {
        return fromoffsetdirection;
    }

    /**
     * Sets the value of the fromoffsetdirection property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setFROMOFFSETDIRECTION(UCODEID_Type value) {
        this.fromoffsetdirection = value;
    }

    /**
     * Gets the value of the fromreferencetype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getFROMREFERENCETYPE() {
        return fromreferencetype;
    }

    /**
     * Sets the value of the fromreferencetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setFROMREFERENCETYPE(TYPE_Type value) {
        this.fromreferencetype = value;
    }

    /**
     * Gets the value of the toreferenceid property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getTOREFERENCEID() {
        return toreferenceid;
    }

    /**
     * Sets the value of the toreferenceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setTOREFERENCEID(LINEARREFERENCEID_Type value) {
        this.toreferenceid = value;
    }

    /**
     * Gets the value of the tooffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTOOFFSET() {
        return tooffset;
    }

    /**
     * Sets the value of the tooffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTOOFFSET(QUANTITY value) {
        this.tooffset = value;
    }

    /**
     * Gets the value of the tooffsetdirection property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getTOOFFSETDIRECTION() {
        return tooffsetdirection;
    }

    /**
     * Sets the value of the tooffsetdirection property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setTOOFFSETDIRECTION(UCODEID_Type value) {
        this.tooffsetdirection = value;
    }

    /**
     * Gets the value of the toreferencetype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTOREFERENCETYPE() {
        return toreferencetype;
    }

    /**
     * Sets the value of the toreferencetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTOREFERENCETYPE(TYPE_Type value) {
        this.toreferencetype = value;
    }

}

==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/RELATEDLINEARREFERENCEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour RELATEDLINEARREFERENCEDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RELATEDLINEARREFERENCEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSETDIRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFERENCETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSETDIRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFERENCETYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELATEDLINEARREFERENCEDETAILS_Type", propOrder = {
    "fromreferenceid",
    "fromoffset",
    "fromoffsetdirection",
    "fromreferencetype",
    "toreferenceid",
    "tooffset",
    "tooffsetdirection",
    "toreferencetype"
})
public class RELATEDLINEARREFERENCEDETAILS_Type {

    @XmlElement(name = "FROMREFERENCEID")
    protected LINEARREFERENCEID_Type fromreferenceid;
    @XmlElement(name = "FROMOFFSET")
    protected QUANTITY fromoffset;
    @XmlElement(name = "FROMOFFSETDIRECTION")
    protected UCODEID_Type fromoffsetdirection;
    @XmlElement(name = "FROMREFERENCETYPE")
    protected TYPE_Type fromreferencetype;
    @XmlElement(name = "TOREFERENCEID")
    protected LINEARREFERENCEID_Type toreferenceid;
    @XmlElement(name = "TOOFFSET")
    protected QUANTITY tooffset;
    @XmlElement(name = "TOOFFSETDIRECTION")
    protected UCODEID_Type tooffsetdirection;
    @XmlElement(name = "TOREFERENCETYPE")
    protected TYPE_Type toreferencetype;

    /**
     * Obtient la valeur de la propriété fromreferenceid.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getFROMREFERENCEID() {
        return fromreferenceid;
    }

    /**
     * Définit la valeur de la propriété fromreferenceid.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setFROMREFERENCEID(LINEARREFERENCEID_Type value) {
        this.fromreferenceid = value;
    }

    /**
     * Obtient la valeur de la propriété fromoffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFROMOFFSET() {
        return fromoffset;
    }

    /**
     * Définit la valeur de la propriété fromoffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFROMOFFSET(QUANTITY value) {
        this.fromoffset = value;
    }

    /**
     * Obtient la valeur de la propriété fromoffsetdirection.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getFROMOFFSETDIRECTION() {
        return fromoffsetdirection;
    }

    /**
     * Définit la valeur de la propriété fromoffsetdirection.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setFROMOFFSETDIRECTION(UCODEID_Type value) {
        this.fromoffsetdirection = value;
    }

    /**
     * Obtient la valeur de la propriété fromreferencetype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getFROMREFERENCETYPE() {
        return fromreferencetype;
    }

    /**
     * Définit la valeur de la propriété fromreferencetype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setFROMREFERENCETYPE(TYPE_Type value) {
        this.fromreferencetype = value;
    }

    /**
     * Obtient la valeur de la propriété toreferenceid.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getTOREFERENCEID() {
        return toreferenceid;
    }

    /**
     * Définit la valeur de la propriété toreferenceid.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setTOREFERENCEID(LINEARREFERENCEID_Type value) {
        this.toreferenceid = value;
    }

    /**
     * Obtient la valeur de la propriété tooffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTOOFFSET() {
        return tooffset;
    }

    /**
     * Définit la valeur de la propriété tooffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTOOFFSET(QUANTITY value) {
        this.tooffset = value;
    }

    /**
     * Obtient la valeur de la propriété tooffsetdirection.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getTOOFFSETDIRECTION() {
        return tooffsetdirection;
    }

    /**
     * Définit la valeur de la propriété tooffsetdirection.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setTOOFFSETDIRECTION(UCODEID_Type value) {
        this.tooffsetdirection = value;
    }

    /**
     * Obtient la valeur de la propriété toreferencetype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTOREFERENCETYPE() {
        return toreferencetype;
    }

    /**
     * Définit la valeur de la propriété toreferencetype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTOREFERENCETYPE(TYPE_Type value) {
        this.toreferencetype = value;
    }

}
